==> haskell-tasty-expected-failure-0.12.3-355.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-expected-failure
version:              0.12.3
visibility:           public
id:                   tasty-expected-failure-0.12.3-CUCx7mkX0SFF73jGMqDeB9
key:                  tasty-expected-failure-0.12.3-CUCx7mkX0SFF73jGMqDeB9
license:              MIT
copyright:            2015 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             http://github.com/nomeata/tasty-expected-failure
synopsis:             Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.

    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.

    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.

    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.

category:             Testing
abi:                  dc9a0b13907fd45fe1fb04e3d99e2eb5
exposed:              True
exposed-modules:      Test.Tasty.ExpectedFailure
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-expected-failure-0.12.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-expected-failure-0.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-expected-failure
hs-libraries:         HStasty-expected-failure-0.12.3-CUCx7mkX0SFF73jGMqDeB9
depends:
    base-4.16.4.0 tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-45V6IUrFvI6FX8Qf0XPHba
    unbounded-delays-0.1.1.1-HyB7dbKDYek99idPmc4TXa

haddock-interfaces:
    /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock

haddock-html:         /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-expected-failure-0.12.3-362.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-expected-failure
version:              0.12.3
visibility:           public
id:                   tasty-expected-failure-0.12.3-Ghmy2hMBDWW7QY984o3kyS
key:                  tasty-expected-failure-0.12.3-Ghmy2hMBDWW7QY984o3kyS
license:              MIT
copyright:            2015 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             http://github.com/nomeata/tasty-expected-failure
synopsis:             Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.

    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.

    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.

    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.

category:             Testing
abi:                  5341b7259145a16e43a59728bcbffff2
exposed:              True
exposed-modules:      Test.Tasty.ExpectedFailure
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-expected-failure-0.12.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-expected-failure-0.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-expected-failure
hs-libraries:         HStasty-expected-failure-0.12.3-Ghmy2hMBDWW7QY984o3kyS
depends:
    base-4.16.4.0 tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7
    unbounded-delays-0.1.1.1-HyB7dbKDYek99idPmc4TXa

haddock-interfaces:
    /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock

haddock-html:         /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
